@@ -41,6 +41,7 @@ OC.L10N.register(
     "Comment:" : "باھا:",
     "You have a new appointment booking \"%s\" from %s" : "سىزدە% s دىن «% s» نى زاكاز قىلىش يېڭى زاكاس تالونى بار",
     "Dear %s, %s (%s) booked an appointment with you." : "ھۆرمەتلىك% s ،% s (% s) سىز بىلەن كۆرۈشۈشنى زاكاز قىلدى.",
+    "Location:" : "ئورنى:",
     "A Calendar app for Nextcloud" : "Nextcloud ئۈچۈن كالېندار دېتالى",
     "Previous day" : "ئالدىنقى كۈن",
     "Previous week" : "ئالدىنقى ھەپتە",
@@ -144,6 +145,7 @@ OC.L10N.register(
     "Share calendar" : "كالېندارنى ئورتاقلىشىش",
     "Unshare from me" : "مەندىن تەڭداشسىز",
     "Save" : "ساقلا",
+    "View" : "كۆرۈش",
     "Import calendars" : "كالېندار ئەكىرىڭ",
     "Please select a calendar to import into …" : "ئىمپورت قىلىدىغان كالېندارنى تاللاڭ.",
     "Filename" : "ھۆججەت ئىسمى",
@@ -159,7 +161,7 @@ OC.L10N.register(
     "No valid files found, aborting import" : "ئۈنۈملۈك ھۆججەت تېپىلمىدى ، ئىمپورتنى ئەمەلدىن قالدۇردى",
     "Import partially failed. Imported {accepted} out of {total}." : "ئىمپورت قىسمەن مەغلۇپ بولدى. {accepted} دىن ئىمپورت قىلىنغان {total} قىلىندى}.",
     "Automatic" : "ئاپتوماتىك",
-    "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
+    "Automatic ({timezone})" : "ئاپتوماتىك ({timezone})",
     "New setting was not saved successfully." : "يېڭى تەڭشەك مۇۋەپپەقىيەتلىك ساقلانمىدى.",
     "Navigation" : "يول باشلاش",
     "Previous period" : "ئالدىنقى مەزگىل",
@@ -178,7 +180,6 @@ OC.L10N.register(
     "Save edited event" : "تەھرىرلەنگەن پائالىيەتنى ساقلاڭ",
     "Delete edited event" : "تەھرىرلەنگەن ۋەقەنى ئۆچۈرۈڭ",
     "Duplicate event" : "كۆپەيتىلگەن ھادىسە",
-    "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
     "or" : "ياكى",
     "Calendar settings" : "كالېندار تەڭشىكى",
     "At event start" : "پائالىيەت باشلانغاندا",
@@ -186,19 +187,18 @@ OC.L10N.register(
     "Failed to save default calendar" : "سۈكۈتتىكى كالېندارنى ساقلىيالمىدى",
     "CalDAV link copied to clipboard." : "CalDAV ئۇلىنىشى چاپلاش تاختىسىغا كۆچۈرۈلدى.",
     "CalDAV link could not be copied to clipboard." : "CalDAV ئۇلانمىسىنى چاپلاش تاختىسىغا كۆچۈرگىلى بولمايدۇ.",
-    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
-    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
-    "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
-    "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
-    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
-    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
-    "Time increments" : "ۋاقىت كۆپەيدى",
-    "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
-    "Default reminder" : "كۆڭۈلدىكى ئەسكەرتىش",
+    "General" : "General",
+    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
     "Copy primary CalDAV address" : "دەسلەپكى CalDAV ئادرېسىنى كۆچۈرۈڭ",
     "Copy iOS/macOS CalDAV address" : "IOS / macOS CalDAV ئادرېسىنى كۆچۈرۈڭ",
-    "Personal availability settings" : "شەخسىي ئىشلىتىش تەڭشىكى",
-    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت",
+    "Enable birthday calendar" : "تۇغۇلغان كۈن كالىندارىنى قوزغىتىڭ",
+    "Show tasks in calendar" : "كالېنداردىكى ۋەزىپىلەرنى كۆرسەت",
+    "Show weekends" : "ھەپتە ئاخىرىنى كۆرسەت",
+    "Show week numbers" : "ھەپتە نومۇرىنى كۆرسەت",
+    "Editing" : "تەھرىرلەش",
+    "Default calendar for incoming invitations" : "كەلگەن تەكلىپلەرنىڭ سۈكۈتتىكى كالېندارى",
+    "Default reminder" : "كۆڭۈلدىكى ئەسكەرتىش",
+    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
     "Appointment schedule successfully created" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك قۇرۇلدى",
     "Appointment schedule successfully updated" : "تەيىنلەش جەدۋىلى مۇۋەپپەقىيەتلىك يېڭىلاندى",
     "0 minutes" : "0 مىنۇت",
@@ -377,6 +377,11 @@ OC.L10N.register(
     "Update this occurrence" : "بۇ ھادىسىنى يېڭىلاڭ",
     "Public calendar does not exist" : "ئاممىۋى كالېندار مەۋجۇت ئەمەس",
     "Maybe the share was deleted or has expired?" : "بەلكىم ھەمبەھىر ئۆچۈرۈلگەن ياكى ۋاقتى توشقان بولۇشى مۇمكىن؟",
+    "Remove participant" : "قاتناشقۇچىنى ئېلىۋېتىڭ",
+    "Yes" : "ھەئە",
+    "No" : "ياق",
+    "Maybe" : "مۇمكىن",
+    "Create" : "قۇر",
     "from {formattedDate}" : "from {formattedDate}",
     "to {formattedDate}" : "to {formattedDate}",
     "on {formattedDate}" : "on {formattedDate}",
@@ -431,6 +436,11 @@ OC.L10N.register(
     "Invite" : "تەكلىپ قىلىڭ",
     "Untitled event" : "نامسىز ھادىسە",
     "Close" : "ياپ",
+    "Selected" : "تاللانغان",
+    "Title" : "ماۋزۇ",
+    "30 min" : "30 مىنۇت",
+    "Participants" : "قاتناشقۇچىلار",
+    "Submit" : "يوللاڭ",
     "Subscribe to {name}" : "{name} غا مۇشتەرى بولۇڭ",
     "Export {name}" : "چىقىرىش {name}",
     "Anniversary" : "يىللىق خاتىرە كۈنى",
@@ -513,13 +523,11 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "PROPFIND خاتالىقىنى تەھلىل قىلغاندا خاتالىق",
     "Appointment not found" : "تەيىنلەنمىدى",
     "User not found" : "ئىشلەتكۈچى تېپىلمىدى",
-    "Create a new conversation" : "يېڭى سۆھبەت قۇر",
-    "Reminder" : "ئەسكەرتىش",
-    "+ Add reminder" : "+ ئەسكەرتىش قوشۇڭ",
-    "Select automatic slot" : "ئاپتوماتىك ئورۇننى تاللاڭ",
-    "with" : "with",
-    "Available times:" : "ئىشلەتكىلى بولىدىغان ۋاقىت:",
-    "Suggestions" : "تەكلىپ",
-    "Details" : "تەپسىلاتى"
+    "Automatic ({detected})" : "ئاپتوماتىك ({detected})",
+    "Shortcut overview" : "تېزلەتمە ئومۇمىي كۆرۈنۈش",
+    "Enable simplified editor" : "ئاددىيلاشتۇرۇلغان تەھرىرلىگۈچنى قوزغىتىڭ",
+    "Limit the number of events displayed in the monthly view" : "ئايلىق كۆرۈنۈشتە كۆرسىتىلگەن پائالىيەت سانىنى چەكلەڭ",
+    "Time increments" : "ۋاقىت كۆپەيدى",
+    "Show keyboard shortcuts" : "كۇنۇپكا تاختىسىنىڭ تېزلەتمىسىنى كۆرسەت"
 },
 "nplurals=2; plural=(n != 1);");
